@@ -31,6 +31,9 @@ class EditorManager(object):
         prefs.register_dialog('Editor settings', self.show_editor_preferences,
             'editor', 'font', 'style', 'margin', 'line', 'tab', 'whitespace')
 
+        prefs.register_dialog('File types', self.edit_contexts, 'file', 'type', 'association')
+
+
         self.escape_stack = []
         self.escape_map = {}
         self.spot_history = []
@@ -318,6 +321,25 @@ class EditorManager(object):
 
         self.goto_last_spot(editor)
 
+
+    def edit_contexts(self, editor):
+        import shutil
+        from os.path import join, exists, dirname
+        from snaked.util import make_missing_dirs
+
+        contexts = join(editor.project_root, '.snaked_project', 'contexts')
+        if not exists(contexts):
+            make_missing_dirs(contexts)
+            shutil.copy(join(dirname(__file__), 'contexts.template'), contexts)
+
+        e = editor.open_file(contexts)
+        e.file_saved.connect(self, 'on_context_saved')
+
+    def on_context_saved(self, editor):
+        editor.message('File type associations changed')
+        self.lang_gussers.clear()
+
+
 class EditorSpot(object):
     def __init__(self, manager, editor):
         self.manager = manager
